==> confidence-json-0.35.1-sources.jar: org/saynotobugs/confidence/json/quality/JsonValueOf.java <==
/*
 * Copyright 2023 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.saynotobugs.confidence.json.quality;

import org.dmfs.express.json.JsonValue;
import org.dmfs.express.json.elementary.JsonText;
import org.dmfs.srcless.annotations.staticfactory.StaticFactories;
import org.saynotobugs.confidence.Quality;
import org.saynotobugs.confidence.description.Text;
import org.saynotobugs.confidence.json.JsonElementAdapter;
import org.saynotobugs.confidence.json.jsonstringadapter.JsonStringElementAdapter;
import org.saynotobugs.confidence.quality.composite.Has;
import org.saynotobugs.confidence.quality.composite.QualityComposition;

/**
 * {@link Quality} of a {@link JsonValue}.
 */
@StaticFactories(value = "Json", packageName = "org.saynotobugs.confidence.json")
public final class JsonValueOf extends QualityComposition<JsonValue>
{
    public JsonValueOf(Quality<? super JsonElementAdapter> delegate)
    {
        super(new Has<>(new Text("JsonValue"), new Text("JsonValue"), jsonValue -> new JsonStringElementAdapter(new JsonText(jsonValue).value()), delegate));
    }

}

==> confidence-json-0.57.0-sources.jar: org/saynotobugs/confidence/json/quality/JsonValueOf.java <==
/*
 * Copyright 2023 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.saynotobugs.confidence.json.quality;

import org.dmfs.express.json.JsonValue;
import org.dmfs.express.json.elementary.JsonText;
import org.dmfs.srcless.annotations.staticfactory.DeprecatedFactories;
import org.dmfs.srcless.annotations.staticfactory.StaticFactories;
import org.saynotobugs.confidence.Quality;
import org.saynotobugs.confidence.description.Text;
import org.saynotobugs.confidence.json.JsonElementAdapter;
import org.saynotobugs.confidence.json.jsonstringadapter.JsonStringElementAdapter;
import org.saynotobugs.confidence.quality.composite.Has;
import org.saynotobugs.confidence.quality.composite.QualityComposition;

/**
 * {@link Quality} of a {@link JsonValue}.
 */
@StaticFactories(
    value = "JsonValue",
    packageName = "org.saynotobugs.confidence.json.quality",
    deprecates = @DeprecatedFactories(value = "Json", packageName = "org.saynotobugs.confidence.json"))
public final class JsonValueOf extends QualityComposition<JsonValue>
{
    public JsonValueOf(Quality<? super JsonElementAdapter> delegate)
    {
        super(new Has<>(new Text("JsonValue"), new Text("JsonValue"), jsonValue -> new JsonStringElementAdapter(new JsonText(jsonValue).value()), delegate));
    }

}
